Module elements

Module elements 

Structs

BorderBuilder
Builder for configuring border properties of a Declaration.
CornerRadiusBuilder
Builder for configuring corner radius properties in a Declaration.
FloatingBuilder
Builder for configuring floating element properties in a Declaration.
ImageBuilder
Builder for configuring image properties in a Declaration.

Enums

FloatingAttachPointType
Represents different attachment points for floating elements.
FloatingAttachToElement
Defines how a floating element is attached to other elements.
PointerCaptureMode
Specifies how pointer capture should behave for floating elements.